// variaveis originais: Lpibc_sa_lcycle, selic_dmn, ipca_seas_qoq_dmn, US_Lpibc_sa_lcycle, ffrate_dmn
// With persistence
tic;

var 
    c           ${c}$
    y           ${y}$
    psi         ${\psi}$
    q           ${q}$
    s           ${s}$
    pih         ${\pi_H}$
    rmc         ${mc}$ 
    ir          ${i}$
    pi          ${\pi}$
    pistar      ${\pi^*}$
    pif         ${\pi_F}$
    ystar       ${y^*}$
    irstar      ${i^*}$
    e_a         ${e^a}$
    e_q         ${e^q}$
    rmcstar     ${mc^*}$
    e_astar     ${e^{a^*}}$

    cstar       $c^*$
    rwage       $rw$
    rwagestar   $rw^*$
    n           $n$
    nstar       $n^*$
    de          $\delta e$
    ch          $c_H$
    chstar      $c_{H^*}$
;

varexo 
    eps_astar $\epsilon^{a^*}$
    eps_irstar  $\epsilon^{i^*}$
    eps_a  $\epsilon^a$
    eps_q  $\epsilon^q$
    eps_ir $\epsilon^i$  
;

parameters 
    alphaa          ${\alpha}$
    etaa            ${\eta}$
    thetah          ${\theta^H}$
    thetaf          ${\theta^F}$
    betaa           ${\beta}$
    phii            ${\phi}$
    sigmaa          ${\sigma}$
    rho_ir          ${\rho^i}$
    psi_pi          ${\psi^{\pi}}$
    psi_y           ${\psi^y}$
    rho_a           ${\rho^a}$
    rho_q           ${\rho^q}$
    rho_astar       ${\rho^{a^*}}$
    rho_ystar       ${\rho^{y^*}}$
    rho_pistar      ${\rho^{\pi^*}}$
    rho_irstar      ${\rho^{i^*}}$
    psi_pistar      ${\psi^{\pi^*}}$
    psi_ystar       ${\psi^{y^*}}$
    sigma_a         ${\sigma^a}$
    sigma_q         ${\sigma^q}$
    sigma_ir        ${\sigma^i}$
    sigma_irstar    ${\sigma^{i^*}}$
    sigma_astar     ${\sigma^{a^*}}$

    h               $h$
    deltah          $\delta_H$
    deltaf          $\delta_F$
    deltahstar      $\delta_{H^*}$
; 

betaa = 0.99 ;
alphaa = 0.45 ;
sigmaa = 1 ; 
phii = 2 ; 
etaa = 1 ; 
thetah = 0.5 ;
thetaf = 0.5 ;
rho_ir = 0.5 ;
psi_pi = 1.5 ;
psi_y = 0.5 ;
rho_a = 0.5 ;
rho_astar =0.8;
rho_q = 0.8 ;
rho_ystar=0.5;
rho_pistar=0.5;
rho_irstar=0.5;
psi_pistar=1.5;
psi_ystar=0.5;
sigma_a = 0.5 ;
sigma_q = 0.5 ;
sigma_ir=0.5;
sigma_irstar=0.5;
sigma_astar=0.5;

h=0.6;
deltah=0.7;
deltaf=0.7;
deltahstar=0.7;

model_local_variable 
    lambdah         ${\lambda^H}$
    lambdaf         ${\lambda^F}$
    lambdahstar     ${\lambda^{H^*}}$
    omega_s         ${\omega^s}$
;

model(linear) ; 
#lambdah = (1-thetah)*(1-thetah*betaa)/thetah;
#lambdaf = (1-thetaf)*(1-thetaf*betaa)/thetaf;
#lambdahstar = (1-thetah)*(1-thetah*betaa)/thetah;
#omega_s = 1+alphaa*(2-alphaa)*(sigmaa*etaa-1);

[name='Euler']                          c - h*c(-1) = c(+1) - h*c - (1 - h)/sigmaa * (ir - pi(+1));
[name='domestic inflation']             pih = betaa * (pih(+1) - deltah*pih) + deltah*pih(-1) + lambdah * rmc;
[name='Real MC']                        rmc = phii*y - (1 + phii)*e_a + alphaa*s + sigmaa/(1 - h)*(c - h*c(-1));
[name='imports inflation']              pif = betaa * (pif(+1) - deltaf*pif) + deltaf*pif(-1) + lambdaf * psi;
[name='UIP with risk premium']          q(+1) - q = ir - pi(+1) - (irstar - pistar(+1))+e_q;
[name='Terms of Trade']                 s = s(-1) + pif - pih ;
[name='Goods Market Clear']             y = (1 - alphaa) * c  + alphaa * etaa * q + alphaa * etaa* s  + alphaa * ystar;
[name='CPI']                            pi = (1 - alphaa)*pih + alphaa *pif  ;
[name='Exo - Tech Shock']               e_a = rho_a * e_a(-1) + eps_a ;
[name='Exo - Risk Premium Shock']       e_q = rho_q * e_q(-1) + eps_q ;
[name='Taylor rule']                    ir = rho_ir * ir(-1) + (1 - rho_ir) *( psi_pi * pi(+1) +psi_y*y)+ eps_ir ;
[name='Int Risk Sharing']               c - h*c(-1) = ystar - h*ystar(-1) + (1 - h)/sigmaa * q ;
[name='World Inflation']                pistar = betaa * (pistar(+1) - deltahstar*pistar) + deltahstar*pistar(-1) + lambdahstar * rmcstar  ;  
[name='World Real MC']                  rmcstar = phii* ystar +sigmaa/(1-h)*(ystar - h*ystar(-1)) - (1 + phii) * e_astar;
[name='World Taylor rule']              irstar = rho_irstar * irstar(-1) + (1 - rho_irstar) * (psi_pistar*pistar(+1) +psi_ystar*ystar) + eps_irstar ;
[name='Exo - World Tech Shock']         e_astar = rho_astar * e_astar(-1) + eps_astar ;

[name='World Consumption']              cstar = ystar;
[name='Local Labour']                   n = y - e_a;
[name='World Labour']                   nstar =  ystar - e_astar;
[name='Local real wage']                rwage = sigmaa*(c - h*c(-1)) + phii*n;
[name='World real wage']                rwagestar = sigmaa*(cstar - h*cstar(-1)) + phii*nstar;
[name='LOP Gap']                        psi = q - (1 - alphaa) * s;
[name='Nominal Exchange Rate']          de = q - q(-1) - pistar + pi;
[name='Domestic C of Home Output']      ch = alphaa*etaa*s + c;
[name='Foreign C of Home Output']       chstar = etaa*(s + psi) + cstar; 
end ;

resid(1);
steady ; 
check ;
model_diagnostics;


write_latex_dynamic_model( write_equation_tags);
write_latex_parameter_table;
write_latex_definitions;

collect_latex_files;

shocks;
var eps_a;      stderr (sigma_a);
var eps_q;      stderr (sigma_q);
var eps_ir;     stderr (sigma_ir);
var eps_irstar; stderr (sigma_irstar); 
var eps_astar;  stderr (sigma_astar);
end; 

stoch_simul(order=1,irf=20,irf_plot_threshold=0);
close all;

estimated_params;
//betaa, beta_pdf, 0.99, 0.005; 
//alphaa, beta_pdf, 0.45, 0.2;
h, beta_pdf, 0.7, 0.1; 
sigmaa, gamma_pdf, 1.0, 0.2; 
phii, gamma_pdf, 2.0, 0.35; 
etaa , gamma_pdf, 1.0, 0.25;     
deltah, beta_pdf, 0.8, 0.1; 
deltaf, beta_pdf, 0.8, 0.1; 
thetah, beta_pdf, 0.5, 0.25; 
thetaf, beta_pdf, 0.5, 0.25; 

rho_a, beta_pdf, 0.8, 0.1;   
rho_astar, beta_pdf, 0.8, 0.1;
rho_q, beta_pdf, 0.8, 0.1;

rho_ir, beta_pdf, 0.5, 0.25; 
psi_pi, uniform_pdf, , , 1.05, 2;
psi_y ,  beta_pdf, 0.5, 0.25;

rho_irstar, beta_pdf, 0.5, 0.25;
psi_pistar, uniform_pdf, , , 1.05, 2;
psi_ystar , beta_pdf, 0.5, 0.25;

stderr eps_a, inv_gamma2_pdf,0.5,inf;
stderr eps_q , inv_gamma2_pdf,0.5,inf;
stderr eps_ir, inv_gamma2_pdf,0.5,inf;
stderr eps_irstar, inv_gamma2_pdf,0.01,inf;
stderr eps_astar, inv_gamma2_pdf,0.5,inf;
                                   
end;

varobs y, ir, pi, ystar, irstar; 
@#define nn =84
@#define rangee = "A1:BK85"


options_.debug=1

estimation(order=1,mode_file=MBZH_00A_mh_mode,load_mh_file, datafile='MyBase_temp.xlsx',xls_range=@{rangee}, nobs=@{nn}, mode_compute=6, mh_replic=200000, mh_nblocks=4,mode_check,mh_tune_jscale);




generate_trace_plots(1);

identification ;

